type token =
  | CODE of (Coqpp_ast.code)
  | COMMENT of (string)
  | IDENT of (string)
  | QUALID of (string)
  | STRING of (string)
  | INT of (int)
  | VERNAC
  | TACTIC
  | GRAMMAR
  | DOC_GRAMMAR
  | EXTEND
  | END
  | DECLARE
  | PLUGIN
  | DEPRECATED
  | ARGUMENT
  | RAW_PRINTED
  | GLOB_PRINTED
  | COMMAND
  | CLASSIFIED
  | STATE
  | PRINTED
  | TYPED
  | INTERPRETED
  | GLOBALIZED
  | SUBSTITUTED
  | BY
  | AS
  | BANGBRACKET
  | HASHBRACKET
  | LBRACKET
  | RBRACKET
  | PIPE
  | ARROW
  | FUN
  | COMMA
  | EQUAL
  | STAR
  | LPAREN
  | RPAREN
  | COLON
  | SEMICOLON
  | GLOBAL
  | TOP
  | FIRST
  | LAST
  | BEFORE
  | AFTER
  | LEVEL
  | LEFTA
  | RIGHTA
  | NONA
  | EOF

open Parsing;;
let _ = parse_error;;
# 12 "coqpp/coqpp_parse.mly"

open Coqpp_ast

let starts s pat =
  let len = String.length s in
  let patlen = String.length pat in
  if patlen <= len && String.sub s 0 patlen = pat then
    Some (String.sub s patlen (len - patlen))
  else None

let ends s pat =
  let len = String.length s in
  let patlen = String.length pat in
  if patlen <= len && String.sub s (len - patlen) patlen = pat then
    Some (String.sub s 0 (len - patlen))
  else None

let between s pat1 pat2 = match starts s pat1 with
| None -> None
| Some s -> ends s pat2  

let without_sep k sep r =
  if sep <> "" then raise Parsing.Parse_error else k r

let parse_user_entry s sep =
  let table = [
    "ne_", "_list", without_sep (fun r -> Ulist1 r);
    "ne_", "_list_sep", (fun sep r -> Ulist1sep (r, sep));
    "", "_list", without_sep (fun r -> Ulist0 r);
    "", "_list_sep", (fun sep r -> Ulist0sep (r, sep));
    "", "_opt", without_sep (fun r -> Uopt r);
  ] in
  let rec parse s sep = function
  | [] ->
    let () = without_sep ignore sep () in
    begin match starts s "tactic" with
    | Some ("0"|"1"|"2"|"3"|"4"|"5" as s) -> Uentryl ("tactic", int_of_string s)
    | Some _ | None -> Uentry s
    end
  | (pat1, pat2, k) :: rem ->
    match between s pat1 pat2 with
    | None -> parse s sep rem
    | Some s ->
      let r = parse s "" table in
      k sep r      
  in
  parse s sep table

let no_code = { code = ""; loc = { loc_start=Lexing.dummy_pos; loc_end=Lexing.dummy_pos} }

# 110 "coqpp/coqpp_parse.ml"
let yytransl_const = [|
  263 (* VERNAC *);
  264 (* TACTIC *);
  265 (* GRAMMAR *);
  266 (* DOC_GRAMMAR *);
  267 (* EXTEND *);
  268 (* END *);
  269 (* DECLARE *);
  270 (* PLUGIN *);
  271 (* DEPRECATED *);
  272 (* ARGUMENT *);
  273 (* RAW_PRINTED *);
  274 (* GLOB_PRINTED *);
  275 (* COMMAND *);
  276 (* CLASSIFIED *);
  277 (* STATE *);
  278 (* PRINTED *);
  279 (* TYPED *);
  280 (* INTERPRETED *);
  281 (* GLOBALIZED *);
  282 (* SUBSTITUTED *);
  283 (* BY *);
  284 (* AS *);
  285 (* BANGBRACKET *);
  286 (* HASHBRACKET *);
  287 (* LBRACKET *);
  288 (* RBRACKET *);
  289 (* PIPE *);
  290 (* ARROW *);
  291 (* FUN *);
  292 (* COMMA *);
  293 (* EQUAL *);
  294 (* STAR *);
  295 (* LPAREN *);
  296 (* RPAREN *);
  297 (* COLON *);
  298 (* SEMICOLON *);
  299 (* GLOBAL *);
  300 (* TOP *);
  301 (* FIRST *);
  302 (* LAST *);
  303 (* BEFORE *);
  304 (* AFTER *);
  305 (* LEVEL *);
  306 (* LEFTA *);
  307 (* RIGHTA *);
  308 (* NONA *);
    0 (* EOF *);
    0|]

let yytransl_block = [|
  257 (* CODE *);
  258 (* COMMENT *);
  259 (* IDENT *);
  260 (* QUALID *);
  261 (* STRING *);
  262 (* INT *);
    0|]

let yylhs = "\255\255\
\001\000\002\000\002\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\004\000\005\000\008\000\008\000\014\000\
\014\000\018\000\018\000\019\000\019\000\021\000\021\000\015\000\
\015\000\016\000\016\000\017\000\017\000\013\000\013\000\022\000\
\022\000\022\000\006\000\023\000\023\000\024\000\024\000\024\000\
\025\000\025\000\026\000\026\000\027\000\029\000\029\000\028\000\
\028\000\033\000\033\000\033\000\034\000\034\000\031\000\031\000\
\032\000\032\000\007\000\035\000\035\000\036\000\036\000\020\000\
\020\000\037\000\030\000\030\000\038\000\038\000\038\000\038\000\
\010\000\010\000\011\000\011\000\039\000\039\000\012\000\012\000\
\040\000\040\000\041\000\041\000\043\000\043\000\045\000\045\000\
\045\000\045\000\046\000\046\000\047\000\047\000\048\000\048\000\
\048\000\044\000\044\000\049\000\042\000\042\000\050\000\050\000\
\051\000\052\000\052\000\053\000\053\000\054\000\054\000\056\000\
\056\000\056\000\056\000\056\000\055\000\055\000\009\000\057\000\
\057\000\058\000\058\000\059\000\059\000\060\000\061\000\061\000\
\061\000\062\000\062\000\063\000\063\000\064\000\064\000\065\000\
\065\000\065\000\065\000\000\000"

let yylen = "\002\000\
\002\000\000\000\002\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\003\000\006\000\012\000\007\000\000\000\
\003\000\000\000\003\000\000\000\003\000\000\000\003\000\000\000\
\004\000\000\000\003\000\000\000\003\000\000\000\003\000\001\000\
\002\000\005\000\008\000\001\000\001\000\000\000\003\000\003\000\
\000\000\002\000\001\000\002\000\010\000\000\000\003\000\000\000\
\003\000\001\000\002\000\003\000\003\000\001\000\000\000\001\000\
\000\000\002\000\007\000\000\000\002\000\000\000\002\000\000\000\
\002\000\006\000\000\000\002\000\001\000\001\000\004\000\006\000\
\001\000\001\000\000\000\004\000\000\000\002\000\000\000\002\000\
\009\000\007\000\001\000\002\000\000\000\001\000\001\000\001\000\
\002\000\002\000\000\000\001\000\000\000\001\000\001\000\001\000\
\001\000\001\000\003\000\005\000\000\000\001\000\001\000\003\000\
\003\000\000\000\001\000\001\000\003\000\003\000\001\000\001\000\
\003\000\003\000\003\000\001\000\001\000\002\000\002\000\000\000\
\002\000\006\000\004\000\001\000\003\000\001\000\000\000\001\000\
\002\000\001\000\003\000\003\000\001\000\001\000\002\000\001\000\
\003\000\003\000\001\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\004\000\005\000\000\000\000\000\000\000\000\000\
\000\000\000\000\140\000\000\000\000\000\006\000\007\000\008\000\
\009\000\010\000\011\000\037\000\000\000\036\000\000\000\000\000\
\000\000\074\000\073\000\000\000\119\000\000\000\000\000\000\000\
\001\000\003\000\000\000\000\000\000\000\000\000\000\000\121\000\
\012\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\061\000\
\000\000\000\000\000\000\000\000\000\000\000\000\123\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\063\000\000\000\000\000\000\000\000\000\013\000\
\080\000\000\000\139\000\000\000\000\000\136\000\000\000\000\000\
\126\000\000\000\130\000\133\000\000\000\032\000\000\000\000\000\
\000\000\000\000\017\000\000\000\015\000\065\000\039\000\040\000\
\042\000\000\000\000\000\000\000\059\000\078\000\076\000\083\000\
\087\000\088\000\000\000\000\000\000\000\000\000\000\000\086\000\
\000\000\000\000\000\000\122\000\000\000\000\000\135\000\000\000\
\033\000\000\000\000\000\000\000\000\000\000\000\069\000\000\000\
\000\000\000\000\000\000\035\000\044\000\089\000\090\000\084\000\
\000\000\000\000\132\000\138\000\137\000\125\000\131\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\068\000\
\000\000\000\000\000\000\000\000\000\000\000\000\092\000\000\000\
\000\000\000\000\000\000\023\000\025\000\027\000\000\000\000\000\
\000\000\000\000\000\000\000\000\049\000\000\000\000\000\000\000\
\000\000\116\000\000\000\000\000\000\000\000\000\102\000\000\000\
\000\000\107\000\000\000\111\000\000\000\000\000\095\000\096\000\
\097\000\000\000\094\000\000\000\034\000\029\000\000\000\000\000\
\000\000\000\000\071\000\066\000\053\000\052\000\047\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\118\000\082\000\000\000\099\000\019\000\000\000\000\000\000\000\
\000\000\110\000\115\000\114\000\113\000\000\000\104\000\105\000\
\109\000\000\000\021\000\014\000\072\000\056\000\000\000\081\000\
\100\000\000\000\000\000\058\000\000\000\045\000"

let yydgoto = "\002\000\
\011\000\012\000\013\000\014\000\015\000\016\000\017\000\018\000\
\019\000\189\000\048\000\061\000\051\000\053\000\098\000\133\000\
\157\000\177\000\209\000\069\000\131\000\096\000\023\000\055\000\
\074\000\107\000\108\000\139\000\165\000\136\000\247\000\251\000\
\162\000\163\000\046\000\058\000\070\000\137\000\078\000\062\000\
\118\000\190\000\119\000\168\000\120\000\169\000\202\000\203\000\
\170\000\191\000\192\000\193\000\194\000\195\000\196\000\197\000\
\029\000\030\000\087\000\088\000\089\000\090\000\091\000\092\000\
\093\000"

let yysindex = "\010\000\
\179\255\000\000\000\000\000\000\093\255\014\255\019\255\118\255\
\027\255\055\255\000\000\018\000\179\255\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\134\255\000\000\141\255\101\255\
\118\255\000\000\000\000\114\255\000\000\118\255\129\255\168\255\
\000\000\000\000\173\255\187\255\167\255\121\255\172\255\000\000\
\000\000\191\255\189\255\197\255\217\255\171\255\182\255\118\255\
\095\255\193\255\189\255\192\255\194\255\178\255\201\255\000\000\
\218\255\194\255\118\255\184\255\214\255\118\255\000\000\060\255\
\003\255\204\255\228\255\199\255\219\255\194\255\231\255\230\255\
\232\255\203\255\000\000\222\255\118\255\195\255\152\255\000\000\
\000\000\202\255\000\000\060\255\069\255\000\000\206\255\207\255\
\000\000\205\255\000\000\000\000\069\255\000\000\003\255\238\255\
\211\255\220\255\000\000\188\255\000\000\000\000\000\000\000\000\
\000\000\213\255\234\255\203\255\000\000\000\000\000\000\000\000\
\000\000\000\000\239\255\243\255\244\255\221\255\223\255\000\000\
\069\255\224\255\210\255\000\000\060\255\060\255\000\000\033\255\
\000\000\250\255\233\255\235\255\225\255\216\255\000\000\229\255\
\188\255\118\255\240\255\000\000\000\000\000\000\000\000\000\000\
\226\255\002\000\000\000\000\000\000\000\000\000\000\000\003\255\
\236\255\014\000\015\000\247\255\003\000\016\000\245\255\000\000\
\241\255\249\255\242\255\021\000\251\255\075\255\000\000\253\255\
\133\255\254\255\021\255\000\000\000\000\000\000\020\000\005\000\
\009\000\057\255\029\000\118\255\000\000\118\255\004\000\188\255\
\252\255\000\000\075\255\084\255\255\255\006\000\000\000\007\000\
\008\000\000\000\011\000\000\000\084\255\012\000\000\000\000\000\
\000\000\013\000\000\000\002\000\000\000\000\000\033\000\019\000\
\194\255\030\000\000\000\000\000\000\000\000\000\000\000\017\000\
\084\255\023\000\022\000\032\000\024\000\075\255\038\000\075\255\
\000\000\000\000\075\255\000\000\000\000\040\000\031\000\025\000\
\035\000\000\000\000\000\000\000\000\000\026\000\000\000\000\000\
\000\000\027\000\000\000\000\000\000\000\000\000\028\000\000\000\
\000\000\044\000\036\000\000\000\046\000\000\000"

let yyrindex = "\000\000\
\051\001\000\000\000\000\000\000\000\000\000\000\000\000\001\000\
\000\000\000\000\000\000\000\000\051\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\001\000\000\000\000\000\
\000\000\000\000\000\000\000\000\001\255\132\255\000\000\000\000\
\000\000\107\255\072\255\250\254\000\000\074\255\000\000\045\000\
\000\000\000\000\142\255\000\000\048\000\000\000\034\000\000\000\
\000\000\048\000\037\000\000\000\000\000\045\000\000\000\175\255\
\000\000\144\255\000\000\000\000\000\000\048\000\000\000\000\000\
\000\000\000\000\000\000\000\000\037\000\000\000\041\000\000\000\
\000\000\016\255\000\000\175\255\000\000\000\000\000\000\206\255\
\000\000\177\255\000\000\000\000\106\255\000\000\000\000\125\255\
\039\000\011\255\000\000\042\000\000\000\000\000\000\000\000\000\
\000\000\067\255\000\000\049\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\175\255\180\255\000\000\000\000\
\000\000\000\000\000\000\000\000\161\255\007\255\000\000\000\000\
\042\000\000\000\047\000\000\000\000\000\000\000\000\000\000\000\
\000\000\051\255\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\108\255\000\000\000\000\000\000\
\240\254\000\000\043\000\000\000\000\000\170\255\000\000\000\000\
\050\000\051\000\000\000\000\000\000\000\000\000\000\000\000\000\
\083\255\000\000\000\000\000\000\000\000\052\000\000\000\042\000\
\004\255\000\000\053\000\000\000\028\255\000\000\000\000\054\000\
\000\000\000\000\055\000\000\000\123\255\000\000\000\000\000\000\
\000\000\000\000\000\000\051\255\000\000\000\000\000\000\000\000\
\048\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\053\000\000\000\000\000\
\000\000\000\000\170\255\000\000\000\000\000\000\000\000\000\000\
\181\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\056\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\039\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\248\255\000\000\252\000\000\000\013\001\000\000\000\000\
\000\000\000\000\000\000\200\255\000\000\164\255\000\000\000\000\
\000\000\217\000\000\000\000\000\000\000\124\255\000\000\000\000\
\145\000\000\000\000\000\000\000\000\000\000\000\255\000\000\000\
\000\000\102\000\000\000\129\000\000\000\000\000\000\000\000\000\
\000\000\126\255\000\000\000\000\112\000\000\000\149\255\000\000\
\052\001\000\000\176\255\000\000\000\000\000\000\215\000\246\255\
\000\000"

let yytablesize = 346
let yytable = "\028\000\
\120\000\076\000\128\000\122\000\160\000\094\000\074\000\074\000\
\074\000\070\000\001\000\070\000\060\000\102\000\038\000\054\000\
\038\000\033\000\074\000\074\000\074\000\028\000\026\000\129\000\
\024\000\054\000\038\000\026\000\026\000\025\000\112\000\112\000\
\112\000\060\000\074\000\129\000\026\000\074\000\070\000\060\000\
\031\000\095\000\074\000\026\000\150\000\074\000\074\000\074\000\
\074\000\060\000\077\000\216\000\074\000\060\000\074\000\086\000\
\218\000\074\000\112\000\171\000\205\000\112\000\082\000\027\000\
\083\000\032\000\112\000\112\000\077\000\112\000\152\000\026\000\
\027\000\083\000\123\000\086\000\086\000\185\000\027\000\186\000\
\219\000\091\000\127\000\016\000\086\000\062\000\026\000\027\000\
\186\000\225\000\084\000\239\000\210\000\020\000\020\000\048\000\
\211\000\048\000\085\000\084\000\091\000\091\000\091\000\037\000\
\016\000\187\000\062\000\085\000\021\000\234\000\147\000\022\000\
\086\000\188\000\187\000\020\000\086\000\086\000\030\000\018\000\
\026\000\027\000\188\000\030\000\030\000\018\000\063\000\064\000\
\030\000\161\000\030\000\030\000\030\000\041\000\075\000\075\000\
\031\000\134\000\134\000\030\000\018\000\031\000\031\000\075\000\
\035\000\134\000\031\000\134\000\031\000\031\000\031\000\036\000\
\231\000\016\000\039\000\024\000\117\000\031\000\016\000\016\000\
\024\000\024\000\117\000\047\000\117\000\016\000\016\000\016\000\
\024\000\024\000\042\000\213\000\028\000\161\000\016\000\043\000\
\024\000\028\000\028\000\003\000\004\000\045\000\199\000\200\000\
\201\000\005\000\006\000\007\000\008\000\044\000\134\000\009\000\
\135\000\028\000\010\000\112\000\113\000\114\000\115\000\116\000\
\117\000\101\000\049\000\106\000\071\000\072\000\127\000\127\000\
\128\000\128\000\052\000\129\000\129\000\050\000\055\000\055\000\
\054\000\056\000\067\000\057\000\065\000\073\000\059\000\075\000\
\079\000\080\000\068\000\097\000\099\000\100\000\101\000\103\000\
\104\000\109\000\105\000\106\000\111\000\124\000\121\000\125\000\
\129\000\130\000\138\000\142\000\132\000\140\000\126\000\143\000\
\144\000\149\000\156\000\145\000\153\000\146\000\158\000\148\000\
\166\000\120\000\120\000\154\000\159\000\155\000\167\000\120\000\
\120\000\120\000\120\000\172\000\164\000\120\000\173\000\174\000\
\120\000\175\000\178\000\176\000\206\000\180\000\179\000\183\000\
\181\000\184\000\208\000\182\000\198\000\212\000\204\000\207\000\
\217\000\229\000\232\000\215\000\237\000\221\000\240\000\222\000\
\243\000\223\000\244\000\227\000\252\000\230\000\254\000\220\000\
\233\000\246\000\002\000\034\000\224\000\226\000\235\000\238\000\
\079\000\081\000\249\000\064\000\043\000\236\000\250\000\066\000\
\245\000\022\000\041\000\248\000\141\000\253\000\214\000\085\000\
\242\000\067\000\050\000\110\000\228\000\046\000\077\000\241\000\
\093\000\040\000\098\000\051\000\151\000\103\000\106\000\000\000\
\108\000\057\000"

let yycheck = "\008\000\
\000\000\058\000\095\000\084\000\137\000\003\001\003\001\004\001\
\005\001\003\001\001\000\005\001\012\001\070\000\021\001\032\001\
\025\000\000\000\003\001\004\001\005\001\030\000\012\001\003\001\
\011\001\042\001\033\001\017\001\018\001\011\001\003\001\004\001\
\005\001\033\001\031\001\003\001\026\001\034\001\032\001\048\000\
\014\001\039\001\039\001\033\001\125\000\042\001\031\001\032\001\
\033\001\049\001\059\000\184\000\049\001\062\000\039\001\064\000\
\187\000\042\001\031\001\152\000\040\001\034\001\003\001\004\001\
\005\001\011\001\039\001\040\001\077\000\042\001\038\001\003\001\
\004\001\005\001\085\000\084\000\085\000\003\001\004\001\005\001\
\188\000\031\001\093\000\012\001\093\000\012\001\003\001\004\001\
\005\001\197\000\031\001\222\000\036\001\001\001\012\001\029\001\
\040\001\031\001\039\001\031\001\050\001\051\001\052\001\003\001\
\033\001\031\001\033\001\039\001\016\001\217\000\121\000\019\001\
\121\000\039\001\031\001\033\001\125\000\126\000\012\001\012\001\
\003\001\004\001\039\001\017\001\018\001\018\001\032\001\033\001\
\022\001\138\000\024\001\025\001\026\001\005\001\003\001\004\001\
\012\001\032\001\033\001\033\001\033\001\017\001\018\001\012\001\
\011\001\040\001\022\001\042\001\024\001\025\001\026\001\011\001\
\209\000\012\001\041\001\012\001\034\001\033\001\017\001\018\001\
\017\001\018\001\040\001\043\001\042\001\024\001\025\001\026\001\
\025\001\026\001\003\001\180\000\012\001\182\000\033\001\003\001\
\033\001\017\001\018\001\001\001\002\001\015\001\050\001\051\001\
\052\001\007\001\008\001\009\001\010\001\003\001\003\001\013\001\
\005\001\033\001\016\001\044\001\045\001\046\001\047\001\048\001\
\049\001\032\001\031\001\034\001\027\001\028\001\032\001\033\001\
\032\001\033\001\022\001\032\001\033\001\023\001\034\001\035\001\
\020\001\001\001\027\001\049\001\028\001\021\001\041\001\006\001\
\041\001\012\001\033\001\024\001\001\001\031\001\012\001\001\001\
\003\001\012\001\003\001\033\001\042\001\032\001\037\001\033\001\
\003\001\031\001\030\001\005\001\025\001\012\001\042\001\005\001\
\005\001\040\001\026\001\031\001\003\001\031\001\039\001\032\001\
\031\001\001\001\002\001\027\001\032\001\027\001\005\001\007\001\
\008\001\009\001\010\001\032\001\029\001\013\001\001\001\001\001\
\016\001\027\001\003\001\017\001\001\001\037\001\034\001\003\001\
\032\001\031\001\018\001\042\001\032\001\001\001\033\001\027\001\
\037\001\001\001\005\001\032\001\005\001\032\001\001\001\033\001\
\001\001\034\001\012\001\031\001\001\001\027\001\001\001\049\001\
\032\001\015\001\000\000\013\000\042\001\042\001\032\001\032\001\
\012\001\062\000\032\001\012\001\012\001\040\001\035\001\051\000\
\040\001\027\001\033\001\042\001\108\000\034\001\182\000\031\001\
\227\000\032\001\032\001\077\000\204\000\031\001\042\001\224\000\
\031\001\030\000\032\001\032\001\126\000\032\001\034\001\255\255\
\034\001\034\001"

let yynames_const = "\
  VERNAC\000\
  TACTIC\000\
  GRAMMAR\000\
  DOC_GRAMMAR\000\
  EXTEND\000\
  END\000\
  DECLARE\000\
  PLUGIN\000\
  DEPRECATED\000\
  ARGUMENT\000\
  RAW_PRINTED\000\
  GLOB_PRINTED\000\
  COMMAND\000\
  CLASSIFIED\000\
  STATE\000\
  PRINTED\000\
  TYPED\000\
  INTERPRETED\000\
  GLOBALIZED\000\
  SUBSTITUTED\000\
  BY\000\
  AS\000\
  BANGBRACKET\000\
  HASHBRACKET\000\
  LBRACKET\000\
  RBRACKET\000\
  PIPE\000\
  ARROW\000\
  FUN\000\
  COMMA\000\
  EQUAL\000\
  STAR\000\
  LPAREN\000\
  RPAREN\000\
  COLON\000\
  SEMICOLON\000\
  GLOBAL\000\
  TOP\000\
  FIRST\000\
  LAST\000\
  BEFORE\000\
  AFTER\000\
  LEVEL\000\
  LEFTA\000\
  RIGHTA\000\
  NONA\000\
  EOF\000\
  "

let yynames_block = "\
  CODE\000\
  COMMENT\000\
  IDENT\000\
  QUALID\000\
  STRING\000\
  INT\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'nodes) in
    Obj.repr(
# 84 "coqpp/coqpp_parse.mly"
  ( _1 )
# 493 "coqpp/coqpp_parse.ml"
               : Coqpp_ast.t))
; (fun __caml_parser_env ->
    Obj.repr(
# 89 "coqpp/coqpp_parse.mly"
  ( [] )
# 499 "coqpp/coqpp_parse.ml"
               : 'nodes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'node) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'nodes) in
    Obj.repr(
# 91 "coqpp/coqpp_parse.mly"
  ( _1 :: _2 )
# 507 "coqpp/coqpp_parse.ml"
               : 'nodes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 95 "coqpp/coqpp_parse.mly"
       ( Code _1 )
# 514 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 96 "coqpp/coqpp_parse.mly"
          ( Comment _1 )
# 521 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'declare_plugin) in
    Obj.repr(
# 97 "coqpp/coqpp_parse.mly"
                 ( _1 )
# 528 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'grammar_extend) in
    Obj.repr(
# 98 "coqpp/coqpp_parse.mly"
                 ( _1 )
# 535 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'vernac_extend) in
    Obj.repr(
# 99 "coqpp/coqpp_parse.mly"
                ( _1 )
# 542 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'tactic_extend) in
    Obj.repr(
# 100 "coqpp/coqpp_parse.mly"
                ( _1 )
# 549 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'argument_extend) in
    Obj.repr(
# 101 "coqpp/coqpp_parse.mly"
                  ( _1 )
# 556 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram) in
    Obj.repr(
# 102 "coqpp/coqpp_parse.mly"
           ( _1 )
# 563 "coqpp/coqpp_parse.ml"
               : 'node))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 106 "coqpp/coqpp_parse.mly"
                        ( DeclarePlugin _3 )
# 570 "coqpp/coqpp_parse.ml"
               : 'declare_plugin))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'qualid_or_ident) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'globals) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'gram_entries) in
    Obj.repr(
# 111 "coqpp/coqpp_parse.mly"
  ( GramExt { gramext_name = _3; gramext_globals = _4; gramext_entries = _5 } )
# 579 "coqpp/coqpp_parse.ml"
               : 'grammar_extend))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 9 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 8 : 'typed_opt) in
    let _5 = (Parsing.peek_val __caml_parser_env 7 : 'printed_opt) in
    let _6 = (Parsing.peek_val __caml_parser_env 6 : 'interpreted_opt) in
    let _7 = (Parsing.peek_val __caml_parser_env 5 : 'globalized_opt) in
    let _8 = (Parsing.peek_val __caml_parser_env 4 : 'substituted_opt) in
    let _9 = (Parsing.peek_val __caml_parser_env 3 : 'raw_printed_opt) in
    let _10 = (Parsing.peek_val __caml_parser_env 2 : 'glob_printed_opt) in
    let _11 = (Parsing.peek_val __caml_parser_env 1 : 'tactic_rules) in
    Obj.repr(
# 125 "coqpp/coqpp_parse.mly"
  ( ArgumentExt {
    argext_name = _3;
    argext_rules = _11;
    argext_rprinter = _9;
    argext_gprinter = _10;
    argext_tprinter = _5;
    argext_interp = _6;
    argext_glob = _7;
    argext_subst = _8;
    argext_type = _4;
  } )
# 604 "coqpp/coqpp_parse.ml"
               : 'argument_extend))
; (fun __caml_parser_env ->
    let _4 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'printed_opt) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'tactic_rules) in
    Obj.repr(
# 137 "coqpp/coqpp_parse.mly"
  ( VernacArgumentExt {
    vernacargext_name = _4;
    vernacargext_printer = _5;
    vernacargext_rules = _6;
  } )
# 617 "coqpp/coqpp_parse.ml"
               : 'argument_extend))
; (fun __caml_parser_env ->
    Obj.repr(
# 145 "coqpp/coqpp_parse.mly"
  ( None )
# 623 "coqpp/coqpp_parse.ml"
               : 'printed_opt))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 146 "coqpp/coqpp_parse.mly"
                  ( Some _3 )
# 630 "coqpp/coqpp_parse.ml"
               : 'printed_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 150 "coqpp/coqpp_parse.mly"
  ( None )
# 636 "coqpp/coqpp_parse.ml"
               : 'raw_printed_opt))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 151 "coqpp/coqpp_parse.mly"
                      ( Some _3 )
# 643 "coqpp/coqpp_parse.ml"
               : 'raw_printed_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 155 "coqpp/coqpp_parse.mly"
  ( None )
# 649 "coqpp/coqpp_parse.ml"
               : 'glob_printed_opt))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 156 "coqpp/coqpp_parse.mly"
                       ( Some _3 )
# 656 "coqpp/coqpp_parse.ml"
               : 'glob_printed_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 160 "coqpp/coqpp_parse.mly"
  ( None )
# 662 "coqpp/coqpp_parse.ml"
               : 'interpreted_modifier_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 161 "coqpp/coqpp_parse.mly"
                          ( Some _2 )
# 669 "coqpp/coqpp_parse.ml"
               : 'interpreted_modifier_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 165 "coqpp/coqpp_parse.mly"
  ( None )
# 675 "coqpp/coqpp_parse.ml"
               : 'interpreted_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'interpreted_modifier_opt) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 166 "coqpp/coqpp_parse.mly"
                                               ( Some (_2,_4) )
# 683 "coqpp/coqpp_parse.ml"
               : 'interpreted_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 170 "coqpp/coqpp_parse.mly"
  ( None )
# 689 "coqpp/coqpp_parse.ml"
               : 'globalized_opt))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 171 "coqpp/coqpp_parse.mly"
                     ( Some _3 )
# 696 "coqpp/coqpp_parse.ml"
               : 'globalized_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 175 "coqpp/coqpp_parse.mly"
  ( None )
# 702 "coqpp/coqpp_parse.ml"
               : 'substituted_opt))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 176 "coqpp/coqpp_parse.mly"
                      ( Some _3 )
# 709 "coqpp/coqpp_parse.ml"
               : 'substituted_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 180 "coqpp/coqpp_parse.mly"
  ( None )
# 715 "coqpp/coqpp_parse.ml"
               : 'typed_opt))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'argtype) in
    Obj.repr(
# 181 "coqpp/coqpp_parse.mly"
                   ( Some _3 )
# 722 "coqpp/coqpp_parse.ml"
               : 'typed_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 185 "coqpp/coqpp_parse.mly"
        ( ExtraArgType _1 )
# 729 "coqpp/coqpp_parse.ml"
               : 'argtype))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'argtype) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 186 "coqpp/coqpp_parse.mly"
                (
    match _2 with
    | "list" -> ListArgType _1
    | "option" ->  OptArgType _1
    | _ -> raise Parsing.Parse_error
  )
# 742 "coqpp/coqpp_parse.ml"
               : 'argtype))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'argtype) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'argtype) in
    Obj.repr(
# 192 "coqpp/coqpp_parse.mly"
                                     ( PairArgType (_2, _4) )
# 750 "coqpp/coqpp_parse.ml"
               : 'argtype))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 6 : 'vernac_entry) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : 'vernac_classifier) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : 'vernac_state) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : 'vernac_rules) in
    Obj.repr(
# 197 "coqpp/coqpp_parse.mly"
  ( VernacExt {
    vernacext_name = _4;
    vernacext_entry = _2;
    vernacext_class = _5;
    vernacext_state = _6;
    vernacext_rules = _7;
  } )
# 767 "coqpp/coqpp_parse.ml"
               : 'vernac_extend))
; (fun __caml_parser_env ->
    Obj.repr(
# 207 "coqpp/coqpp_parse.mly"
          ( None )
# 773 "coqpp/coqpp_parse.ml"
               : 'vernac_entry))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 208 "coqpp/coqpp_parse.mly"
       ( Some _1 )
# 780 "coqpp/coqpp_parse.ml"
               : 'vernac_entry))
; (fun __caml_parser_env ->
    Obj.repr(
# 212 "coqpp/coqpp_parse.mly"
  ( ClassifDefault )
# 786 "coqpp/coqpp_parse.ml"
               : 'vernac_classifier))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 213 "coqpp/coqpp_parse.mly"
                     ( ClassifCode _3 )
# 793 "coqpp/coqpp_parse.ml"
               : 'vernac_classifier))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 214 "coqpp/coqpp_parse.mly"
                      ( ClassifName _3 )
# 800 "coqpp/coqpp_parse.ml"
               : 'vernac_classifier))
; (fun __caml_parser_env ->
    Obj.repr(
# 218 "coqpp/coqpp_parse.mly"
  ( None )
# 806 "coqpp/coqpp_parse.ml"
               : 'vernac_state))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 219 "coqpp/coqpp_parse.mly"
              ( Some _2 )
# 813 "coqpp/coqpp_parse.ml"
               : 'vernac_state))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'vernac_rule) in
    Obj.repr(
# 223 "coqpp/coqpp_parse.mly"
              ( [_1] )
# 820 "coqpp/coqpp_parse.ml"
               : 'vernac_rules))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'vernac_rule) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'vernac_rules) in
    Obj.repr(
# 224 "coqpp/coqpp_parse.mly"
                           ( _1 :: _2 )
# 828 "coqpp/coqpp_parse.ml"
               : 'vernac_rules))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 8 : 'vernac_attributes_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 7 : 'rule_state) in
    let _5 = (Parsing.peek_val __caml_parser_env 5 : 'ext_tokens) in
    let _7 = (Parsing.peek_val __caml_parser_env 3 : 'rule_deprecation) in
    let _8 = (Parsing.peek_val __caml_parser_env 2 : 'rule_classifier) in
    let _10 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 229 "coqpp/coqpp_parse.mly"
  ( {
      vernac_atts = _2;
      vernac_state = _3;
      vernac_toks = _5;
      vernac_depr = _7;
      vernac_class= _8;
      vernac_body = _10;
  } )
# 847 "coqpp/coqpp_parse.ml"
               : 'vernac_rule))
; (fun __caml_parser_env ->
    Obj.repr(
# 240 "coqpp/coqpp_parse.mly"
  ( None )
# 853 "coqpp/coqpp_parse.ml"
               : 'rule_state))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 241 "coqpp/coqpp_parse.mly"
                             ( Some _2 )
# 860 "coqpp/coqpp_parse.ml"
               : 'rule_state))
; (fun __caml_parser_env ->
    Obj.repr(
# 245 "coqpp/coqpp_parse.mly"
  ( None )
# 866 "coqpp/coqpp_parse.ml"
               : 'vernac_attributes_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'vernac_attributes) in
    Obj.repr(
# 246 "coqpp/coqpp_parse.mly"
                                         ( Some _2 )
# 873 "coqpp/coqpp_parse.ml"
               : 'vernac_attributes_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'vernac_attribute) in
    Obj.repr(
# 250 "coqpp/coqpp_parse.mly"
                   ( [_1] )
# 880 "coqpp/coqpp_parse.ml"
               : 'vernac_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'vernac_attribute) in
    Obj.repr(
# 251 "coqpp/coqpp_parse.mly"
                             ( [_1] )
# 887 "coqpp/coqpp_parse.ml"
               : 'vernac_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'vernac_attribute) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'vernac_attributes) in
    Obj.repr(
# 252 "coqpp/coqpp_parse.mly"
                                               ( _1 :: _3 )
# 895 "coqpp/coqpp_parse.ml"
               : 'vernac_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'qualid_or_ident) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'qualid_or_ident) in
    Obj.repr(
# 256 "coqpp/coqpp_parse.mly"
                                        ( (_1, _3) )
# 903 "coqpp/coqpp_parse.ml"
               : 'vernac_attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qualid_or_ident) in
    Obj.repr(
# 257 "coqpp/coqpp_parse.mly"
                  ( (_1, _1) )
# 910 "coqpp/coqpp_parse.ml"
               : 'vernac_attribute))
; (fun __caml_parser_env ->
    Obj.repr(
# 261 "coqpp/coqpp_parse.mly"
  ( false )
# 916 "coqpp/coqpp_parse.ml"
               : 'rule_deprecation))
; (fun __caml_parser_env ->
    Obj.repr(
# 262 "coqpp/coqpp_parse.mly"
             ( true )
# 922 "coqpp/coqpp_parse.ml"
               : 'rule_deprecation))
; (fun __caml_parser_env ->
    Obj.repr(
# 266 "coqpp/coqpp_parse.mly"
  ( None )
# 928 "coqpp/coqpp_parse.ml"
               : 'rule_classifier))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 267 "coqpp/coqpp_parse.mly"
           ( Some _2 )
# 935 "coqpp/coqpp_parse.ml"
               : 'rule_classifier))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'tactic_deprecated) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'tactic_level) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'tactic_rules) in
    Obj.repr(
# 272 "coqpp/coqpp_parse.mly"
  ( TacticExt { tacext_name = _3; tacext_deprecated = _4; tacext_level = _5; tacext_rules = _6 } )
# 945 "coqpp/coqpp_parse.ml"
               : 'tactic_extend))
; (fun __caml_parser_env ->
    Obj.repr(
# 276 "coqpp/coqpp_parse.mly"
  ( None )
# 951 "coqpp/coqpp_parse.ml"
               : 'tactic_deprecated))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 277 "coqpp/coqpp_parse.mly"
                  ( Some _2 )
# 958 "coqpp/coqpp_parse.ml"
               : 'tactic_deprecated))
; (fun __caml_parser_env ->
    Obj.repr(
# 281 "coqpp/coqpp_parse.mly"
  ( None )
# 964 "coqpp/coqpp_parse.ml"
               : 'tactic_level))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : int) in
    Obj.repr(
# 282 "coqpp/coqpp_parse.mly"
            ( Some _2 )
# 971 "coqpp/coqpp_parse.ml"
               : 'tactic_level))
; (fun __caml_parser_env ->
    Obj.repr(
# 286 "coqpp/coqpp_parse.mly"
  ( [] )
# 977 "coqpp/coqpp_parse.ml"
               : 'tactic_rules))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'tactic_rule) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'tactic_rules) in
    Obj.repr(
# 287 "coqpp/coqpp_parse.mly"
                           ( _1 :: _2 )
# 985 "coqpp/coqpp_parse.ml"
               : 'tactic_rules))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'ext_tokens) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 292 "coqpp/coqpp_parse.mly"
  ( { tac_toks = _3; tac_body = _6 } )
# 993 "coqpp/coqpp_parse.ml"
               : 'tactic_rule))
; (fun __caml_parser_env ->
    Obj.repr(
# 296 "coqpp/coqpp_parse.mly"
  ( [] )
# 999 "coqpp/coqpp_parse.ml"
               : 'ext_tokens))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'ext_token) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'ext_tokens) in
    Obj.repr(
# 297 "coqpp/coqpp_parse.mly"
                       ( _1 :: _2 )
# 1007 "coqpp/coqpp_parse.ml"
               : 'ext_tokens))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 301 "coqpp/coqpp_parse.mly"
         ( ExtTerminal _1 )
# 1014 "coqpp/coqpp_parse.ml"
               : 'ext_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 302 "coqpp/coqpp_parse.mly"
        (
  let e = parse_user_entry _1 "" in
  ExtNonTerminal (e, TokNone) 
  )
# 1024 "coqpp/coqpp_parse.ml"
               : 'ext_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 306 "coqpp/coqpp_parse.mly"
                            (
  let e = parse_user_entry _1 "" in
  ExtNonTerminal (e, TokName _3)
  )
# 1035 "coqpp/coqpp_parse.ml"
               : 'ext_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 310 "coqpp/coqpp_parse.mly"
                                         (
  let e = parse_user_entry _1 _5 in
  ExtNonTerminal (e, TokName _3)
)
# 1047 "coqpp/coqpp_parse.ml"
               : 'ext_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 317 "coqpp/coqpp_parse.mly"
         ( _1 )
# 1054 "coqpp/coqpp_parse.ml"
               : 'qualid_or_ident))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 318 "coqpp/coqpp_parse.mly"
        ( _1 )
# 1061 "coqpp/coqpp_parse.ml"
               : 'qualid_or_ident))
; (fun __caml_parser_env ->
    Obj.repr(
# 322 "coqpp/coqpp_parse.mly"
  ( [] )
# 1067 "coqpp/coqpp_parse.ml"
               : 'globals))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'idents) in
    Obj.repr(
# 323 "coqpp/coqpp_parse.mly"
                                ( _3 )
# 1074 "coqpp/coqpp_parse.ml"
               : 'globals))
; (fun __caml_parser_env ->
    Obj.repr(
# 327 "coqpp/coqpp_parse.mly"
  ( [] )
# 1080 "coqpp/coqpp_parse.ml"
               : 'idents))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'qualid_or_ident) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'idents) in
    Obj.repr(
# 328 "coqpp/coqpp_parse.mly"
                         ( _1 :: _2 )
# 1088 "coqpp/coqpp_parse.ml"
               : 'idents))
; (fun __caml_parser_env ->
    Obj.repr(
# 332 "coqpp/coqpp_parse.mly"
  ( [] )
# 1094 "coqpp/coqpp_parse.ml"
               : 'gram_entries))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'gram_entry) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'gram_entries) in
    Obj.repr(
# 333 "coqpp/coqpp_parse.mly"
                          ( _1 :: _2 )
# 1102 "coqpp/coqpp_parse.ml"
               : 'gram_entries))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 8 : 'qualid_or_ident) in
    let _3 = (Parsing.peek_val __caml_parser_env 6 : 'reuse) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : 'rules_opt) in
    Obj.repr(
# 338 "coqpp/coqpp_parse.mly"
  ( { gentry_name = _1; gentry_rules = GDataReuse (_3, _6); } )
# 1111 "coqpp/coqpp_parse.ml"
               : 'gram_entry))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : 'qualid_or_ident) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : 'position_opt) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'levels) in
    Obj.repr(
# 340 "coqpp/coqpp_parse.mly"
  ( { gentry_name = _1; gentry_rules = GDataFresh (_3, _5); } )
# 1120 "coqpp/coqpp_parse.ml"
               : 'gram_entry))
; (fun __caml_parser_env ->
    Obj.repr(
# 344 "coqpp/coqpp_parse.mly"
      ( None )
# 1126 "coqpp/coqpp_parse.ml"
               : 'reuse))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 345 "coqpp/coqpp_parse.mly"
               ( Some _2 )
# 1133 "coqpp/coqpp_parse.ml"
               : 'reuse))
; (fun __caml_parser_env ->
    Obj.repr(
# 349 "coqpp/coqpp_parse.mly"
  ( None )
# 1139 "coqpp/coqpp_parse.ml"
               : 'position_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'position) in
    Obj.repr(
# 350 "coqpp/coqpp_parse.mly"
           ( Some _1 )
# 1146 "coqpp/coqpp_parse.ml"
               : 'position_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 354 "coqpp/coqpp_parse.mly"
        ( First )
# 1152 "coqpp/coqpp_parse.ml"
               : 'position))
; (fun __caml_parser_env ->
    Obj.repr(
# 355 "coqpp/coqpp_parse.mly"
       ( Last )
# 1158 "coqpp/coqpp_parse.ml"
               : 'position))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 356 "coqpp/coqpp_parse.mly"
                ( Before _2 )
# 1165 "coqpp/coqpp_parse.ml"
               : 'position))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 357 "coqpp/coqpp_parse.mly"
               ( After _2 )
# 1172 "coqpp/coqpp_parse.ml"
               : 'position))
; (fun __caml_parser_env ->
    Obj.repr(
# 361 "coqpp/coqpp_parse.mly"
  ( None )
# 1178 "coqpp/coqpp_parse.ml"
               : 'string_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 362 "coqpp/coqpp_parse.mly"
         ( Some _1 )
# 1185 "coqpp/coqpp_parse.ml"
               : 'string_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 366 "coqpp/coqpp_parse.mly"
  ( None )
# 1191 "coqpp/coqpp_parse.ml"
               : 'assoc_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'assoc) in
    Obj.repr(
# 367 "coqpp/coqpp_parse.mly"
        ( Some _1 )
# 1198 "coqpp/coqpp_parse.ml"
               : 'assoc_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 371 "coqpp/coqpp_parse.mly"
        ( LeftA )
# 1204 "coqpp/coqpp_parse.ml"
               : 'assoc))
; (fun __caml_parser_env ->
    Obj.repr(
# 372 "coqpp/coqpp_parse.mly"
         ( RightA )
# 1210 "coqpp/coqpp_parse.ml"
               : 'assoc))
; (fun __caml_parser_env ->
    Obj.repr(
# 373 "coqpp/coqpp_parse.mly"
       ( NonA )
# 1216 "coqpp/coqpp_parse.ml"
               : 'assoc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'level) in
    Obj.repr(
# 377 "coqpp/coqpp_parse.mly"
        ( [_1] )
# 1223 "coqpp/coqpp_parse.ml"
               : 'levels))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'level) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'levels) in
    Obj.repr(
# 378 "coqpp/coqpp_parse.mly"
                    ( _1 :: _3 )
# 1231 "coqpp/coqpp_parse.ml"
               : 'levels))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'string_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'assoc_opt) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'rules_opt) in
    Obj.repr(
# 383 "coqpp/coqpp_parse.mly"
  ( { grule_label = _1; grule_assoc = _2; grule_prods = _4; } )
# 1240 "coqpp/coqpp_parse.ml"
               : 'level))
; (fun __caml_parser_env ->
    Obj.repr(
# 387 "coqpp/coqpp_parse.mly"
  ( [] )
# 1246 "coqpp/coqpp_parse.ml"
               : 'rules_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'rules) in
    Obj.repr(
# 388 "coqpp/coqpp_parse.mly"
        ( _1 )
# 1253 "coqpp/coqpp_parse.ml"
               : 'rules_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'rule) in
    Obj.repr(
# 392 "coqpp/coqpp_parse.mly"
       ( [_1] )
# 1260 "coqpp/coqpp_parse.ml"
               : 'rules))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'rule) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'rules) in
    Obj.repr(
# 393 "coqpp/coqpp_parse.mly"
                  ( _1 :: _3 )
# 1268 "coqpp/coqpp_parse.ml"
               : 'rules))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'symbols_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Coqpp_ast.code) in
    Obj.repr(
# 398 "coqpp/coqpp_parse.mly"
  ( { gprod_symbs = _1; gprod_body = _3; } )
# 1276 "coqpp/coqpp_parse.ml"
               : 'rule))
; (fun __caml_parser_env ->
    Obj.repr(
# 402 "coqpp/coqpp_parse.mly"
  ( [] )
# 1282 "coqpp/coqpp_parse.ml"
               : 'symbols_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'symbols) in
    Obj.repr(
# 403 "coqpp/coqpp_parse.mly"
          ( _1 )
# 1289 "coqpp/coqpp_parse.ml"
               : 'symbols_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'symbol) in
    Obj.repr(
# 407 "coqpp/coqpp_parse.mly"
         ( [_1] )
# 1296 "coqpp/coqpp_parse.ml"
               : 'symbols))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'symbol) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'symbols) in
    Obj.repr(
# 408 "coqpp/coqpp_parse.mly"
                           ( _1 :: _3 )
# 1304 "coqpp/coqpp_parse.ml"
               : 'symbols))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'gram_tokens) in
    Obj.repr(
# 412 "coqpp/coqpp_parse.mly"
                          ( (Some _1, _3) )
# 1312 "coqpp/coqpp_parse.ml"
               : 'symbol))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'gram_tokens) in
    Obj.repr(
# 413 "coqpp/coqpp_parse.mly"
              ( (None, _1) )
# 1319 "coqpp/coqpp_parse.ml"
               : 'symbol))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qualid_or_ident) in
    Obj.repr(
# 417 "coqpp/coqpp_parse.mly"
                  ( GSymbQualid (_1, None) )
# 1326 "coqpp/coqpp_parse.ml"
               : 'gram_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'qualid_or_ident) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 418 "coqpp/coqpp_parse.mly"
                               ( GSymbQualid (_1, Some _3) )
# 1334 "coqpp/coqpp_parse.ml"
               : 'gram_token))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'gram_tokens) in
    Obj.repr(
# 419 "coqpp/coqpp_parse.mly"
                            ( GSymbParen _2 )
# 1341 "coqpp/coqpp_parse.ml"
               : 'gram_token))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'rules) in
    Obj.repr(
# 420 "coqpp/coqpp_parse.mly"
                          ( GSymbProd _2 )
# 1348 "coqpp/coqpp_parse.ml"
               : 'gram_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 421 "coqpp/coqpp_parse.mly"
         ( GSymbString _1 )
# 1355 "coqpp/coqpp_parse.ml"
               : 'gram_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'gram_token) in
    Obj.repr(
# 425 "coqpp/coqpp_parse.mly"
             ( [_1] )
# 1362 "coqpp/coqpp_parse.ml"
               : 'gram_tokens))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'gram_token) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'gram_tokens) in
    Obj.repr(
# 426 "coqpp/coqpp_parse.mly"
                         ( _1 :: _2 )
# 1370 "coqpp/coqpp_parse.ml"
               : 'gram_tokens))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_entries) in
    Obj.repr(
# 431 "coqpp/coqpp_parse.mly"
  ( GramExt { gramext_name = ""; gramext_globals=[]; gramext_entries = _2 } )
# 1377 "coqpp/coqpp_parse.ml"
               : 'doc_gram))
; (fun __caml_parser_env ->
    Obj.repr(
# 434 "coqpp/coqpp_parse.mly"
  ( [] )
# 1383 "coqpp/coqpp_parse.ml"
               : 'doc_gram_entries))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'doc_gram_entry) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_entries) in
    Obj.repr(
# 435 "coqpp/coqpp_parse.mly"
                                   ( _1 :: _2 )
# 1391 "coqpp/coqpp_parse.ml"
               : 'doc_gram_entries))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'qualid_or_ident) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'doc_gram_rules) in
    Obj.repr(
# 440 "coqpp/coqpp_parse.mly"
  ( { gentry_name = _1;
      gentry_rules = GDataFresh (None, [{ grule_label = None; grule_assoc = None; grule_prods = _5; }]) } )
# 1400 "coqpp/coqpp_parse.ml"
               : 'doc_gram_entry))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'qualid_or_ident) in
    Obj.repr(
# 443 "coqpp/coqpp_parse.mly"
  ( { gentry_name = _1;
      gentry_rules = GDataFresh (None, [{ grule_label = None; grule_assoc = None; grule_prods = []; }]) } )
# 1408 "coqpp/coqpp_parse.ml"
               : 'doc_gram_entry))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_rule) in
    Obj.repr(
# 448 "coqpp/coqpp_parse.mly"
                ( [_1] )
# 1415 "coqpp/coqpp_parse.ml"
               : 'doc_gram_rules))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'doc_gram_rule) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_rules) in
    Obj.repr(
# 449 "coqpp/coqpp_parse.mly"
                                    ( _1 :: _3 )
# 1423 "coqpp/coqpp_parse.ml"
               : 'doc_gram_rules))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_symbols_opt) in
    Obj.repr(
# 453 "coqpp/coqpp_parse.mly"
                       ( { gprod_symbs = _1; gprod_body = no_code; } )
# 1430 "coqpp/coqpp_parse.ml"
               : 'doc_gram_rule))
; (fun __caml_parser_env ->
    Obj.repr(
# 457 "coqpp/coqpp_parse.mly"
  ( [] )
# 1436 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbols_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_symbols) in
    Obj.repr(
# 458 "coqpp/coqpp_parse.mly"
                   ( _1 )
# 1443 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbols_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'doc_gram_symbols) in
    Obj.repr(
# 459 "coqpp/coqpp_parse.mly"
                             ( _1 )
# 1450 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbols_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_symbol) in
    Obj.repr(
# 463 "coqpp/coqpp_parse.mly"
                  ( [_1] )
# 1457 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbols))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'doc_gram_symbols) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_symbol) in
    Obj.repr(
# 464 "coqpp/coqpp_parse.mly"
                                             ( _1 @ [_3] )
# 1465 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbols))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_gram_tokens) in
    Obj.repr(
# 468 "coqpp/coqpp_parse.mly"
                                   ( (Some _1, _3) )
# 1473 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbol))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_gram_tokens) in
    Obj.repr(
# 469 "coqpp/coqpp_parse.mly"
                       ( (None, _1) )
# 1480 "coqpp/coqpp_parse.ml"
               : 'doc_gram_symbol))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_gram_token) in
    Obj.repr(
# 473 "coqpp/coqpp_parse.mly"
                      ( [_1] )
# 1487 "coqpp/coqpp_parse.ml"
               : 'doc_gram_gram_tokens))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'doc_gram_gram_token) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'doc_gram_gram_tokens) in
    Obj.repr(
# 474 "coqpp/coqpp_parse.mly"
                                           ( _1 :: _2 )
# 1495 "coqpp/coqpp_parse.ml"
               : 'doc_gram_gram_tokens))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'qualid_or_ident) in
    Obj.repr(
# 478 "coqpp/coqpp_parse.mly"
                  ( GSymbQualid (_1, None) )
# 1502 "coqpp/coqpp_parse.ml"
               : 'doc_gram_gram_token))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'doc_gram_gram_tokens) in
    Obj.repr(
# 479 "coqpp/coqpp_parse.mly"
                                     ( GSymbParen _2 )
# 1509 "coqpp/coqpp_parse.ml"
               : 'doc_gram_gram_token))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'doc_gram_rules) in
    Obj.repr(
# 480 "coqpp/coqpp_parse.mly"
                                   ( GSymbProd _2 )
# 1516 "coqpp/coqpp_parse.ml"
               : 'doc_gram_gram_token))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 481 "coqpp/coqpp_parse.mly"
         ( GSymbString _1 )
# 1523 "coqpp/coqpp_parse.ml"
               : 'doc_gram_gram_token))
(* Entry file *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Coqpp_ast.t)
